﻿currentDBVersion = 1.1

-- declare defaults to be used in the DB
DATABASE_DEFAULTS = {
  profile =
  {
    scanGuildBank = false,
    displayMode = "",
    gdisplayMode = "",
    displayHints = true,
    TipTacSkin = false,
  },
}


function Liquid_Wealth:CheckMasterDatabase()
  if (not Liquid_Wealth.db.global.dbversion) then
    Liquid_Wealth.db.global.dbversion = currentDBVersion
  elseif Liquid_Wealth.db.global.dbversion < currentDBVersion then
    StaticPopupDialogs["LWRESETDB"] = {
      text = "Liquid-Wealth, needs to wipe your database in order to upgrade to a new format structure. \nThis will also reload your UI.",
      button1 = "OK",
      OnAccept = function()
        Liquid_Wealth:resetMasterDatabases()
      end,
      timeout = 0,
      whileDead = 1,
      hideOnEscape = 1
    };
    StaticPopup_Show("LWRESETDB");
  end

  if not Liquid_Wealth.db.realm.guild then --Check To See If Guilds Master Index Is Present
    Liquid_Wealth.db.realm.guild = {};
  end
  if not Liquid_Wealth.db.realm.toon then --Check To See If Toons Master Index Is Present
    Liquid_Wealth.db.realm.toon = {};
  end
  if (not Liquid_Wealth.db.profile.selectedAuctionAddon) or (Liquid_Wealth.db.profile.selectedAuctionAddon == "") then --Checks To See If Selected Auction Addon Is Listed
    Liquid_Wealth:SetDefaultAuctionAPI();
  end
end

function Liquid_Wealth:removeToonFromDB(Char)
  StaticPopupDialogs["LW_CLEARTOONFROMDB"] = {
    text = "Do you want to clear this toon's data: " .. Liquid_Wealth:BuildIcons(Liquid_Wealth.db.realm.toon[Char].unitID, 20) .. " " .. "|c" .. Liquid_Wealth:ClassColor(Liquid_Wealth.db.realm.toon[Char].unitID) .. Char .. "|r" .. "\nA UI Reload Is Required",
    button1 = "Yes",
    button2 = "No",
    OnAccept = function()
      Liquid_Wealth.db.realm.toon[Char] = nil
      ReloadUI();
    end,
    timeout = 0,
    whileDead = true,
    hideOnEscape = true,
  }
  StaticPopup_Show("LW_CLEARTOONFROMDB")
end

--Reset all data inside of the databased
function Liquid_Wealth:resetMasterDatabases()
  Liquid_Wealth.db:ResetDB('Default')
  Liquid_Wealth.db:ResetProfile(DATABASE_DEFAULTS)
  if (not Liquid_Wealth.db.profile.selectedAuctionAddon) or (Liquid_Wealth.db.profile.selectedAuctionAddon == "") then --Checks To See If Selected Auction Addon Is Listed
    Liquid_Wealth:SetDefaultAuctionAPI();
  end
  ReloadUI()
end

--Loop though all of the Auction supported addons to see if there are loaded, 1st addon it finds, it will use that for the aunction prices
function Liquid_Wealth:SetDefaultAuctionAPI()
  for index, value in pairs(Liquid_Wealth.AuctioneerAddons) do
    if IsAddOnLoaded(value.name) then
      Liquid_Wealth.db.profile.selectedAuctionAddon = value.name
      break
    end
  end
  --This will fix the Acution scaning code from erroring if it dont find anddon when on 1st run
  if (not Liquid_Wealth.db.profile.selectedAuctionAddon) or (Liquid_Wealth.db.profile.selectedAuctionAddon == "") then Liquid_Wealth.db.profile.selectedAuctionAddon = ""; end
end

function Liquid_Wealth:CheckGuildBank(GuildName)
  if Liquid_Wealth.db.realm.guild[GuildName] then
    return true
  end
end


function Liquid_Wealth:CovGuildBankRankToDB(tblRankList)
  local strRankList = ""
  for index, value in pairs(tblRankList) do
    strRankList = strRankList .. tostring(value) .. ":"
  end
  return strRankList
end

function Liquid_Wealth:CovGuildBankItemDataToDB(Name, Texture, isViewable, VenderTotal, AuctionTotal) --Convert GuildTabData to my format (Name:Texture:isViewable:GuildRankLevel:VENDERTOTAL:ACUTIONTOTAL)
  return Name .. ":" .. Texture .. ":" .. isViewable .. ":" .. VenderTotal .. ":" .. AuctionTotal
end

function Liquid_Wealth:CovGuildBankItemDataFromDB(GuildName, banktab)
  if Liquid_Wealth.db.realm.guild[GuildName][banktab] == "" or Liquid_Wealth.db.realm.guild[GuildName][banktab] == nil then
    return nil
  else
    rawString = Liquid_Wealth.db.realm.guild[GuildName][banktab]
    local Name, Texture, isViewable, VenderTotal, AuctionTotal = strsplit(":", rawString);
    return Name, Texture, isViewable, VenderTotal, AuctionTotal
  end
end

function Liquid_Wealth:CheckToonEntery(varPlayer, varAccountType, varPSK, varSex, varRace, varClass)
  -- Create DB structure for new toon
  local vguildName, vguildRankName, vguildRankIndex = GetGuildInfo("Player");
  if vguildName == nil or vguildRankName == nil or vguildRankIndex == nil then
    vguildName = "NONE"
    vguildRankName = "NONE"
    vguildRankIndex = "NONE"
  end
  if not Liquid_Wealth.db.realm.toon[varPlayer] then --Checks to see if current toon is in the database
    Liquid_Wealth.db.realm.toon[varPlayer] = {};
    Liquid_Wealth.db.realm.toon[varPlayer].accountID =
    {
      Type = varAccountType,
      PSK = varPSK,
    }
    Liquid_Wealth.db.realm.toon[varPlayer].unitID = varSex .. ":" .. varRace .. ":" .. varClass
    Liquid_Wealth.db.realm.toon[varPlayer].bagID = {};
    Liquid_Wealth.db.realm.toon[varPlayer].playergold = 0;
    Liquid_Wealth.db.realm.toon[varPlayer].lastChecked = 0;
    Liquid_Wealth.db.realm.toon[varPlayer].guildInfo =
    {
      guildName = vguildName,
      guildRankIndex = vguildRankIndex,
      guildRankName = vguildRankName,
    }
  end
  --Checks the current toon guild information, if there is not information, fill it in, if it has changed, update it.
  --Note: Might have to check to see about non-guilded members
  if (strlower(Liquid_Wealth.db.realm.toon[varPlayer].guildInfo.guildName) ~= strlower(vguildName) or strlower(Liquid_Wealth.db.realm.toon[varPlayer].guildInfo.guildRankIndex) ~= strlower(vguildRankIndex) or strlower(Liquid_Wealth.db.realm.toon[varPlayer].guildInfo.guildRankName) ~= strlower(vguildRankName)) then
    Liquid_Wealth.db.realm.toon[varPlayer].guildInfo =
    {
      guildName = vguildName,
      guildRankIndex = vguildRankIndex,
      guildRankName = vguildRankName,
    }
  end
end

--Convert BagInfo to my format [BagID]=(BagItemLink:VENDERTOTAL:ACUTIONTOTAL)
--New Format [BagID]=(BagItemLink:BagIconPath:BagName:VENDERTOTAL:ACUTIONTOTAL)
function Liquid_Wealth:ConvItemDataToDB(BagItemLink, BagIconPath, BagName, VenderTotal, AuctionTotal)
  local convString = "";
  if not (BagItemLink == "Bank") and not (BagItemLink == "Backpack") and not (BagItemLink == "NONE") then --Bought Bags
    local _, itemId, _, _, _, _, _, _, _ = strsplit(":", BagItemLink)
    convString = itemId .. ":" .. BagIconPath .. ":" .. BagName .. ":" .. VenderTotal .. ":" .. AuctionTotal;
  else
    convString = BagItemLink .. ":" .. BagIconPath .. ":" .. BagName .. ":" .. VenderTotal .. ":" .. AuctionTotal; --Bags Bank or Player
  end
  return convString;
end

--Convert BagInfo from my format [BagID]=(BagItemLink:VENDERTOTAL:ACUTIONTOTAL)
function Liquid_Wealth:ConvItemDataFromDB(BagId, Player)
  if not Liquid_Wealth.db.realm.toon[Player].bagID[BagId] then return "NOSCAN", 0, 0, 0, 0 end; --There is no entery in the database, but that means it could have not been scaned yet
  local rawString = Liquid_Wealth.db.realm.toon[Player].bagID[BagId];
  local BagItemLink, BagIconPath, BagName, VenderTotal, AuctionTotal = strsplit(":", rawString);
  return BagItemLink, BagIconPath, BagName, tonumber(VenderTotal), tonumber(AuctionTotal);
end

function Liquid_Wealth:SelectedToonDatabase(Toon)
  table.foreach(Liquid_Wealth.db.realm.toon, print)
end

--Builds a hex ID that is used for to commfired remote sending.
--Note: This function was used in the Ace2 version, this function gets called but its not doing anything but generating a hex code.
function Liquid_Wealth:genHexPSK()
  ranString = ""
  for i = 1, 8 do
    tempVar = ""
    tempVar = math.random(0, 15)
    if tempVar == 10 then
      ranString = ranString .. "A"
    elseif tempVar == 11 then
      ranString = ranString .. "B"
    elseif tempVar == 12 then
      ranString = ranString .. "C"
    elseif tempVar == 13 then
      ranString = ranString .. "D"
    elseif tempVar == 14 then
      ranString = ranString .. "E"
    elseif tempVar == 15 then
      ranString = ranString .. "F"
    else
      ranString = ranString .. tempVar
    end
  end
  return ranString
end
